@@ -33,7 +33,7 @@ WantedBy=multi-user.target\
 def create_nginx_file(project_path,prj_name,domain_name):
     def wrapper():
         os.mkdir("/etc/nginx/sites-available")
-        with open(f"/etc/nginx/sites-available/{prj_name}","w") as f:
+        with open(f"/etc/nginx/sites-available/{prj_name}.conf","w") as f:
             f.write(f"""\
 server {{
     listen 80;
